@@ -1,4 +1,4 @@
-## Date-time egression tests for R >= 4.3.0
+## Date-time regression tests for R >= 4.3.0
 ## originally added to reg-tests-1d.R
 
 .pt <- proc.time()
@@ -529,6 +529,43 @@ stopifnot(exprs = {
 stopifnot(b1 == b2)
 
 
+## range(<Date>|<POSIXt>, finite = TRUE) [R-devel mails, Davis Vaughan and MM, April 28, 2023ff]
+d <- .Date(c(10, Inf, 11, 12, Inf))
+(dN <- c(d, .Date(c(NA, NaN))))
+## Just the numbers :
+str(x  <- unclass(d))
+str(xN <- unclass(dN), vec.len=9)
+stopifnot(exprs = {
+    identical3(print(range(d)), .Date(range(unclass(d))),# "1970-01-11" "Inf"
+               c(min(d),max(d)))
+    is.na(range(dN))
+    identical3(range(d, finite = TRUE), .Date(range(x, finite=TRUE)),
+               range(dN,finite = TRUE) -> rd)
+    identical(rd, structure(c(10, 12), class = "Date"))
+})
+## POSIXct/lt -----
+ct <- as.POSIXct(d)
+ctN<- as.POSIXct(dN)
+lt <- as.POSIXlt(ct)
+ltN<- as.POSIXlt(ctN)
+str(y  <- unclass(ct))
+str(yN <- unclass(ctN), vec.len=9)
+stopifnot(exprs = {
+    identical(print(range(ct)), .POSIXct(range(unclass(ct)), tz="UTC"))
+    identical3(range(ct, finite = TRUE), .POSIXct(range(y, finite=TRUE), tz="UTC"),
+               range(ctN,finite = TRUE) -> rct)
+    is.na(range(ctN))
+    identical(range(ctN, na.rm=TRUE), range(ct))
+    identical(rct, structure(c(10, 12) * 24*60*60,
+                             class = c("POSIXct", "POSIXt"), tzone = "UTC"))
+    ## POSIXlt
+    identical3(print(range(lt)), as.POSIXlt(range(ct)), # "1970-01-11" "Inf"
+               c(min(lt), max(lt))) # failed for a few days
+    identical3(range(lt, finite = TRUE), as.POSIXlt(rct),
+               range(ltN,finite = TRUE))
+    is.na(range(ltN))
+    identical(range(ltN, na.rm=TRUE), range(lt))
+})
 
 
 ## Losing 1 sec in ct -> lt conversion for tzcode=internal (USE_INTERNAL_MKTIME) -- PR#16856
